==> haskell-monad-par-0.3.6-16-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-monad-par.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 monad-par
version:              0.3.6
visibility:           public
id:                   monad-par-0.3.6-5k0ULeoZzdXDMLPx8hlBxb
key:                  monad-par-0.3.6-5k0ULeoZzdXDMLPx8hlBxb
license:              BSD-3-Clause
copyright:            (c) Simon Marlow 2011
maintainer:
    Simon Marlow <marlowsd@gmail.com>, Ryan Newton <rrnewton@gmail.com>

author:               Simon Marlow, Ryan Newton
stability:            Experimental
homepage:             https://github.com/simonmar/monad-par
synopsis:             A library for parallel programming based on a monad
description:
    The '\''Par'\'' monad offers a simple API for parallel programming.  The
    library works for parallelising both pure and @IO@ computations,
    although only the pure version is deterministic.  The default
    implementation provides a work-stealing scheduler and supports
    forking tasks that are much lighter weight than IO-threads.

    For complete documentation see "Control.Monad.Par".

    Some examples of use can be found in the @examples/@ directory of
    the source package.

    Other related packages:

    * @abstract-par@ provides the type classes that abstract over different
    implementations of the @Par@ monad.

    * @monad-par-extras@ provides extra combinators and monad transformers layered on top of
    the @Par@ monad.

    Changes in 0.3.4 relative to 0.3:

    * Fix bugs that cause "thread blocked indefinitely on MVar" crashes.

    * Added "Control.Monad.Par.IO"

category:             Control,Parallelism,Monads
abi:                  e9f03b7f00c00471d89873461b907ec8
exposed:              True
exposed-modules:
    Control.Monad.Par Control.Monad.Par.IO
    Control.Monad.Par.Scheds.Direct Control.Monad.Par.Scheds.Sparks
    Control.Monad.Par.Scheds.Trace
    Control.Monad.Par.Scheds.TraceInternal

hidden-modules:       Control.Monad.Par.Scheds.DirectInternal
import-dirs:          /usr/lib/ghc-9.2.8/site-local/monad-par-0.3.6
library-dirs:         /usr/lib/ghc-9.2.8/site-local/monad-par-0.3.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-monad-par
hs-libraries:         HSmonad-par-0.3.6-5k0ULeoZzdXDMLPx8hlBxb
depends:
    abstract-deque-0.3-HTt11DaBCAZ4NakYJVdRfA
    abstract-par-0.3.3-ISux4E1QYRJK5C39S1lmJd array-0.5.4.0
    base-4.16.4.0 containers-0.6.5.1 deepseq-1.4.6.1
    monad-par-extras-0.3.3-3aTtkyp2VYM31ji0cTI1u7 mtl-2.2.2
    mwc-random-0.15.0.2-1pNGiFgHV9QFWwJpoJMQB7
    parallel-3.2.2.0-KgDyPHm89eYAjQsIhXthC1

haddock-interfaces:   /usr/share/doc/haskell-monad-par/html/monad-par.haddock
haddock-html:         /usr/share/doc/haskell-monad-par/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-monad-par-0.3.6-19-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-monad-par.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 monad-par
version:              0.3.6
visibility:           public
id:                   monad-par-0.3.6-I8dZRbzeXh52yVzP3u20gU
key:                  monad-par-0.3.6-I8dZRbzeXh52yVzP3u20gU
license:              BSD-3-Clause
copyright:            (c) Simon Marlow 2011
maintainer:
    Simon Marlow <marlowsd@gmail.com>, Ryan Newton <rrnewton@gmail.com>

author:               Simon Marlow, Ryan Newton
stability:            Experimental
homepage:             https://github.com/simonmar/monad-par
synopsis:             A library for parallel programming based on a monad
description:
    The '\''Par'\'' monad offers a simple API for parallel programming.  The
    library works for parallelising both pure and @IO@ computations,
    although only the pure version is deterministic.  The default
    implementation provides a work-stealing scheduler and supports
    forking tasks that are much lighter weight than IO-threads.

    For complete documentation see "Control.Monad.Par".

    Some examples of use can be found in the @examples/@ directory of
    the source package.

    Other related packages:

    * @abstract-par@ provides the type classes that abstract over different
    implementations of the @Par@ monad.

    * @monad-par-extras@ provides extra combinators and monad transformers layered on top of
    the @Par@ monad.

    Changes in 0.3.4 relative to 0.3:

    * Fix bugs that cause "thread blocked indefinitely on MVar" crashes.

    * Added "Control.Monad.Par.IO"

category:             Control,Parallelism,Monads
abi:                  aa74a56c7a1bfc9e4d4585794b710846
exposed:              True
exposed-modules:
    Control.Monad.Par Control.Monad.Par.IO
    Control.Monad.Par.Scheds.Direct Control.Monad.Par.Scheds.Sparks
    Control.Monad.Par.Scheds.Trace
    Control.Monad.Par.Scheds.TraceInternal

hidden-modules:       Control.Monad.Par.Scheds.DirectInternal
import-dirs:          /usr/lib/ghc-9.2.8/site-local/monad-par-0.3.6
library-dirs:         /usr/lib/ghc-9.2.8/site-local/monad-par-0.3.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-monad-par
hs-libraries:         HSmonad-par-0.3.6-I8dZRbzeXh52yVzP3u20gU
depends:
    abstract-deque-0.3-I5blivNTkjm7hdvVT6iIoo
    abstract-par-0.3.3-ISux4E1QYRJK5C39S1lmJd array-0.5.4.0
    base-4.16.4.0 containers-0.6.5.1 deepseq-1.4.6.1
    monad-par-extras-0.3.3-95kXn1cCWSp8Oo76ghjav9 mtl-2.2.2
    mwc-random-0.15.1.0-L7uo6hvot2QA4Ry7jntvwx
    parallel-3.2.2.0-KgDyPHm89eYAjQsIhXthC1

haddock-interfaces:   /usr/share/doc/haskell-monad-par/html/monad-par.haddock
haddock-html:         /usr/share/doc/haskell-monad-par/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
